@@ -67,7 +67,7 @@ xmalloc (size_t size)
   assert (vp != NULL);
   if (vp == NULL)
     {
-	fprintf (stderr, "virtual memory exhausted\n");//
+      fprintf (stderr, "virtual memory exhausted\n");
       exit (EXIT_FAILURE);
     }
   return vp;
@@ -1172,35 +1172,35 @@ print_structure (avltr_tree *tree, avltr_node *node, int level)
 
   if (node == NULL)
     {
-	printf (" :nil"); //
+      printf (" :nil");
       return;
     }
   else if (level >= 10)
     {
-	printf ("Too deep, giving up.\n");//
+      printf ("Too deep, giving up.\n");
       done = 1;
       return;
     }
   else if (node == &tree->root)
     {
-	printf (" root");//
+      printf (" root");
       return;
     }
-  printf (" %c%d", lc[level % 5], (int) node->data);//
+  printf (" %c%d", lc[level % 5], (int) node->data);
   fflush (stdout);
 
-  print_structure (tree, node->link[0], level + 1);//
+  print_structure (tree, node->link[0], level + 1);
   fflush (stdout);
 
   if (node->rtag == PLUS)
-      print_structure (tree, node->link[1], level + 1);//
+    print_structure (tree, node->link[1], level + 1);
   else if (node->link[1] != &tree->root)
-      printf (" :%d", (int) node->link[1]->data);//
+    printf (" :%d", (int) node->link[1]->data);
   else
-      printf (" :r");//
+    printf (" :r");
   fflush (stdout);
 
-  printf ("%c", rc[level % 5]);//
+  printf ("%c", rc[level % 5]);
   fflush (stdout);
 }
 
@@ -1215,7 +1215,7 @@ compare_ints (const void *a, const void *b, void *param unused)
 void
 print_int (void *a, void *param unused)
 {
-    printf (" %d", (int) a);//
+  printf (" %d", (int) a);
 }
 
 /* Linearly print contents of TREE. */
@@ -1223,7 +1223,7 @@ void
 print_contents (avltr_tree *tree)
 {
   avltr_walk (tree, print_int, NULL);
-  printf ("\n");//
+  printf ("\n");
 }
 
 /* Examine NODE in a avl tree.  *COUNT is increased by the number of
@@ -1248,7 +1248,7 @@ recurse_tree (avltr_tree *tree, avltr_node *node, int *count, int parent,
       assert (d >= 0 && d < TREE_SIZE);
       if (nodes[d / 8] & (1 << (d % 8)))
 	{
-	    printf (" Arrived at node %d by two different paths.\n", d);//
+	  printf (" Arrived at node %d by two different paths.\n", d);
 	  done = 1;
 	}
       else
@@ -1261,7 +1261,7 @@ recurse_tree (avltr_tree *tree, avltr_node *node, int *count, int parent,
 	{
 	  if (node->link[1] == NULL)
 	    {
-		printf (" Null thread link.\n");//
+	      printf (" Null thread link.\n");
 	      done = 1;
 	    }
 	  nr = recurse_tree (tree, node->link[1], count, d, 1, nodes, threads);
@@ -1272,7 +1272,7 @@ recurse_tree (avltr_tree *tree, avltr_node *node, int *count, int parent,
 	  assert (dr >= 0 && dr < TREE_SIZE);
 	  if (threads[dr / 8] & (1 << dr % 8))
 	    {
-		printf (" Multiple threads to node %d.\n", d);//
+	      printf (" Multiple threads to node %d.\n", d);
 	      done = 1;
 	    }
 	  threads[dr / 8] |= 1 << (dr % 8);
@@ -1280,8 +1280,7 @@ recurse_tree (avltr_tree *tree, avltr_node *node, int *count, int parent,
 
       if (nr - nl != node->bal)
 	{
-	    printf //
-	      (" Node %d has incorrect balance: right height=%d, "
+	  printf (" Node %d has incorrect balance: right height=%d, "
 		  "left height=%d, difference=%d, but balance factor=%d.\n",
 		  d, nr, nl, nr - nl, node->bal);
 	  done = 1;
@@ -1289,7 +1288,7 @@ recurse_tree (avltr_tree *tree, avltr_node *node, int *count, int parent,
       
       if (node->bal < -1 || node->bal > 1)
 	{
-	    printf (" Node %d has invalid balance factor %d.\n", d, node->bal);//
+	  printf (" Node %d has invalid balance factor %d.\n", d, node->bal);
 	  done = 1;
 	}
       
@@ -1298,13 +1297,13 @@ recurse_tree (avltr_tree *tree, avltr_node *node, int *count, int parent,
 	  assert (dir == -1 || dir == +1);
 	  if (dir == -1 && d > parent)
 	    {
-		printf (" Node %d is smaller than its left child %d.\n",//
+	      printf (" Node %d is smaller than its left child %d.\n",
 		      parent, d);
 	      done = 1;
 	    }
 	  else if (dir == +1 && d < parent)
 	    {
-		printf (" Node %d is larger than its right child %d.\n",//
+	      printf (" Node %d is larger than its right child %d.\n",
 		      parent, d);
 	      done = 1;
 	    }
@@ -1334,8 +1333,7 @@ verify_tree (avltr_tree *tree)
     
     if (count != tree->count)
       {
-	  printf //
-	    (" Tree should have %d nodes, but tree count by recursive "
+	printf (" Tree should have %d nodes, but tree count by recursive "
 		"descent is %d.\n", tree->count, count);
 	done = 1;
       }
@@ -1347,8 +1345,7 @@ verify_tree (avltr_tree *tree)
 
 	if (thread && !node)
 	  {
-	      printf //
-		  (" A thread leads to ``node'' %d, "
+	    printf (" A thread leads to ``node'' %d, "
 		    "which is not in the tree.", i);
 	    done = 1;
 	  }
@@ -1365,12 +1362,12 @@ verify_tree (avltr_tree *tree)
       {
 	if (((int) *data) < last)
 	  {
-	      printf (" Misordered right threads.\n");//
+	    printf (" Misordered right threads.\n");
 	    abort ();
 	  }
 	else if (((int) *data) == last)
 	  {
-	      printf (" Loop in right threads detected on %d.\n", last);//
+	    printf (" Loop in right threads detected on %d.\n", last);
 	    abort ();
 	  }
 	last = (int) *data;
@@ -1379,8 +1376,7 @@ verify_tree (avltr_tree *tree)
 
     if (count != tree->count)
       {
-	  printf//
-	    (" Tree should have %d nodes, but tree count by right threads "
+	printf (" Tree should have %d nodes, but tree count by right threads "
 		"is %d.\n", tree->count, count);
 	done = 1;
       }
@@ -1423,18 +1419,18 @@ compare_trees (avltr_node *a, avltr_node *b)
   diff |= ((a->rtag == PLUS) ^ (b->rtag == PLUS));
   if (diff)
     {
-	printf (" Copied nodes differ: %d b=%d a->bal=%d b->bal=%d a:",//
+      printf (" Copied nodes differ: %d b=%d a->bal=%d b->bal=%d a:",
 	      (int) a->data, (int) b->data, a->bal, b->bal);
       if (a->link[0])
-	  printf ("l");//
+	printf ("l");
       if (a->link[1])
-	  printf ("r");//
-      printf (" b:"); //
+	printf ("r");
+      printf (" b:");
       if (b->link[0])
-	  printf ("l");//
+	printf ("l");
       if (b->link[1])
-	  printf ("r");//
-      printf ("\n");//
+	printf ("r");
+      printf ("\n");
       abort ();
     }
   if (a->link[0] != NULL)
@@ -1486,7 +1482,7 @@ main (int argc, char **argv)
       avltr_tree *tree;
       int i;
       
-      printf ("Iteration %4d/%4d: seed=%5d", iteration, N_ITERATIONS, seed);//
+      printf ("Iteration %4d/%4d: seed=%5d", iteration, N_ITERATIONS, seed);
       fflush (stdout);
       
       srand (seed++);
@@ -1514,7 +1510,7 @@ main (int argc, char **argv)
 	    compare_trees (tree->root.link[0], copy->root.link[0]);
 	  else if (copy->root.link[0] != NULL)
 	    {
-		printf (" Empty tree results in nonempty copy.\n");//
+	      printf (" Empty tree results in nonempty copy.\n");
 	      abort ();
 	    }
 	  avltr_destroy (copy, NULL);
